@@ -4,7 +4,7 @@ use strict;
 use POSIX qw/locale_h/;
 use locale;
 use vars qw ($VERSION @ISA @REGEXS);
-$VERSION = '0.76_03';
+$VERSION = '0.76_05';
 $VERSION = eval $VERSION;
 
 push @REGEXS, qr/
@@ -511,15 +511,13 @@ sub _VERSION {
     my $class = ref($obj) || $obj;
 
     no strict 'refs';
-    eval "require $class" unless %{"$class\::"}; # already existing
-    return undef if $@ =~ /Can't locate/ and not defined $req;
-    
-    if ( not %{"$class\::"} and $] >= 5.008) { # file but no package
+    if ( exists $INC{"$class.pm"} and not %{"$class\::"} and $] >= 5.008) {
+	 # file but no package
 	require Carp;
 	Carp::croak( "$class defines neither package nor VERSION"
 	    ."--version check failed");
     }
-    
+
     my $version = eval "\$$class\::VERSION";
     if ( defined $version ) {
 	local $^W if $] <= 5.008;
